# ieee1905

This package provides -

1. **libieee1905.so** - Library to encode/decode ieee1905 CMDUs and TLVs

2. **ieee1905d** - User space ieee1905 daemon that provide IEEE1905 stack along with Plugin support.

3. **lib1905hle.so** - HLE library with ALME command support over TCP


            UBUS
        +------------------------+
        |       ieee1905d        |  user daemon (AL + Ubus + Plugin + ALME)
        +------------------------+
        |     libieee1905.so     |  IEEE1905 cmdu/tlv support
        +------------------------+


The library 'libieee1905.so' is responsible encoding/decoding cmdu and TLVs to c-structures and vice-versa.

The 'ieee1905d' daemon initializes and starts the 1905 AL. It reads the UCI config file '/etc/config/ieee1905' and initialises the configured interfaces for 1905 AL. It is responsible for processing/sending/receiving CMDUs as per the specification. It also provides ubus objects to expose internal database objects.

>NOTE: In absence of a standard, every vendor is free to implement their own HLE <--> ALME interface. Any IPC mechanism may be used.
The 'meshComms' project has the ALME interface implemented as TCP client/server, where the ALME side has a TCP server listening for incoming TCP requests from the HLE at a pre-defined port. This package also support ALME over TCP based on compile time flag 'ALME_OVER_TCP', in absence of this compile time flag the 'ieee1905d' should not listen for ALME messages over TCP.

Here, UBUS interface is added for the HLE <==> ALME commuication.

Along with the ubus alme method, this package also provide a library **'lib1905hle.so'** to provide the ALME message querying functionality over TCP/IP.

----------------------------------------------------------------------------------------------------

#### AL Ubus interface
**ieee1905d** creates the following UBUS objects and methods -

```json
root@iopsys:~#
root@iopsys:~# ubus -v list ieee1905
'ieee1905' @1e76a83b
        "info":{}
        "interfaces":{}
        "topology":{"remote_mac":"String"}
        "neighbors":{}
        "alme":{"cmd":"String","data":"String"}
root@iopsys:~#
root@iopsys:~# ubus -v list ieee1905.al.< interface-name >
'ieee1905.al.< interface-name >' @db35d2de
        "info":{}
        "neighbors":{}
        "link_info":{}
        "topology":{"remote_mac":"String"}
```

- For more info on the `ieee1905` ubus API see [link](./docs/api/ieee1905.md)
- For more info on the `ieee1905.al.<interface-name>` ubus API see [link](./docs/api/ieee1905.al.ifname.md)

>NOTE 1: In "alme" method the "cmd" method parameter is a string and value of the string is as defined in IEEE1905 - Chapter 5.1.

>NOTE 2: The "< interface-name >" is the al-interface as defined in uci, there might be multiple "ieee1905.al.< interface-name >" object each mapped to one enabled al-iface section in ieee1905 uci.

------------------------------------------------------------------------------------------------------

#### UCI config '/etc/config/ieee1905'

```json
config ieee1905 'ieee1905'
        option enabled '1'
        option debug  true
        option debug_level  2
        option macaddress 'auto'
        option registrar 0
        option cmdu_event 1
        option map_plugin 0

config security 'security'
        list method 'PBC'
        option key 'TESTPASSWORD'

config al-iface
        option enabled 1
        option ifname 'br-lan'
        option media 'bridge'
```

> Definition of elements in 'ieee1905' uci section

| Parameter    |          Definition/meaning                                                  |
|--------------|------------------------------------------------------------------------------|
| enabled      | Enable/disable ieee1905 stack                                                |
| debug        | Enable/disable debug logs                                                    |
| debug_level  | debug log level (0 => No log, 1 => Errors, 2 => Warning, 3 => Info, 4 => All)|
| macaddress   | Al macaddress, allowed valued "valid mac-address" or "auto"                  |
| registrar    | Enable/disable registrar functionality                                       |
| cmdu_event   | If enabled, broadcast some cmdu (topology, pbc etc) in ieee1905.event ubus event|
| map_plugin   | If enabled, use map-plugin to handle map CMDUs (only if plugin is available) |

In case of macaddress is configured as auto, ieee1905 configures the al-mac based on internal algorithm.



> Definition of elements in 'security' uci section

| Parameter    |          Definition/meaning                                                  |
|--------------|------------------------------------------------------------------------------|
| method       | Security setup method (PBC is supported right now)                           |
| key          | Network key for configured setup method                                      |


> Definition of elements in 'al-iface' uci section

| Parameter    |          Definition/meaning                                                  |
|--------------|------------------------------------------------------------------------------|
| enabled      | Enabled al-iface interfaces will be part of ieee1905 stack                   |
| ifname       | Interface name                                                               |
| media        | Interface media type (bridge/eth/wifi)                                       |

If media is configured as bridge and there are wireless interface in that bridge, ieee1905 registers the wireless interfaces automatically.

- For more info on the `ieee1905` uci API see [link](./docs/api/uci.ieee1905.md)

------------------------------------------------------------------------------------------------------

#### Plugins
'ieee1905d' has support for plugins, plugin must be aligned with 'plugin.h', and it must be placed in '/usr/lib/ieee1905' directory.

List of supported plugin(s):
1. Map-2 Plugin (provided by map-1905)

Follow plugin specific documentation for detailed info on that plugin.

> Note : This dynamic library gets loaded based on 'map_plugin' uci parameter.

------------------------------------------------------------------------------------------------------

#### ALME SAP example over Ubus

  * **List alme ubus object for available options**

```json
root@iopsys:/tmp# ubus -v list ieee1905
'ieee1905' @79d9448b
        "alme":{"cmd":"String","data":"String"}
root@iopsys:/tmp#
```

  * **Get list of supported ALME commands**

```json
root@iopsys:/tmp# ubus call ieee1905 alme
{
        "cmd(s)": [
                "ALME-GET-INTF-LIST.request",
                "ALME-SET-INTF-PWR-STATE.request",
                "ALME-GET-INTF-PWR-STATE.request",
                "ALME-SET-FWD-RULE.request",
                "ALME-GET-FWD-RULES.request",
                "ALME-MODIFY-FWD-RULE.request",
                "ALME-REMOVE-FWD-RULE.request",
                "ALME-GET-METRIC.request",
                "ALME_TYPE_CUSTOM_COMMAND_REQUEST"
        ]
}
root@iopsys:/tmp#
```

  * **Query list of configured interfaces in AL**

```json
root@iopsys:~# ubus call ieee1905 alme '{"cmd":"ALME-GET-INTF-LIST.request"}'
{
        "interface_descriptors_nr": 1,
        "interface_descriptors": [
                {
                        "interface_address": "00:22:07:76:5c:54",
                        "media_type": 0,
                        "bridge_flag": 1,
                        "vendor_specific_info_nr": 0,
                        "vendor_specific": [

                        ]
                }
        ]
}
root@iopsys:/tmp#
```

  * **Get metric of all the AL(s) in network**

```json
root@iopsys:/tmp#
root@iopsys:/tmp# ubus call ieee1905 alme '{"cmd":"ALME-GET-METRIC.request"}'
{
        "metrics_nr": 1,
        "metrics": [
                {
                        "neighbor_dev_address": "02:22:07:6d:5e:d7",
                        "local_intf_address": "00:22:07:76:5c:54",
                        "bridge_flag": 2,
                        "tlv_type": "TLV_TYPE_TRANSMITTER_LINK_METRIC",
                        "local_al_address": "02:22:07:76:5c:57",
                        "neighbor_al_address": "02:22:07:6d:5e:d7",
                        "transmitter_link_metrics_nr": 1,
                        "tx_link_metrics": [
                                {
                                        "local_interface_address": "00:22:07:76:5c:54",
                                        "neighbor_interface_address": "00:22:07:6d:5e:d7",
                                        "intf_type": 0,
                                        "bridge_flag": 1,
                                        "packet_errors": 0,
                                        "transmitted_packets": 1141,
                                        "mac_throughput_capacity": 0,
                                        "link_availability": 100,
                                        "phy_rate": 0
                                }
                        ],
                        "tlv_type": "TLV_TYPE_RECEIVER_LINK_METRIC",
                        "local_al_address": "02:22:07:76:5c:57",
                        "neighbor_al_address": "02:22:07:6d:5e:d7",
                        "receiver_link_metrics_nr": 1,
                        "rx_link_metrics": [
                                {
                                        "local_interface_address": "00:22:07:76:5c:54",
                                        "neighbor_interface_address": "00:22:07:6d:5e:d7",
                                        "intf_type": 0,
                                        "packet_errors": 0,
                                        "packets_received": 17308,
                                        "rssi": 0
                                }
                        ]
                }
        ]
}
root@iopsys:/tmp#
```

  * **Get metric of a specific AL having mac (02:22:07:6d:5e:d7)**

```json
root@iopsys:/tmp# ubus call ieee1905 alme '{"cmd":"ALME-GET-METRIC.request", "data":"02:22:07:6d:5e:d7"}'
{
        "metrics_nr": 1,
        "metrics": [
                {
                        "neighbor_dev_address": "02:22:07:6d:5e:d7",
                        "local_intf_address": "00:22:07:76:5c:54",
                        "bridge_flag": 2,
                        "tlv_type": "TLV_TYPE_TRANSMITTER_LINK_METRIC",
                        "local_al_address": "02:22:07:76:5c:57",
                        "neighbor_al_address": "02:22:07:6d:5e:d7",
                        "transmitter_link_metrics_nr": 1,
                        "tx_link_metrics": [
                                {
                                        "local_interface_address": "00:22:07:76:5c:54",
                                        "neighbor_interface_address": "00:22:07:6d:5e:d7",
                                        "intf_type": 0,
                                        "bridge_flag": 1,
                                        "packet_errors": 0,
                                        "transmitted_packets": 1223,
                                        "mac_throughput_capacity": 0,
                                        "link_availability": 100,
                                        "phy_rate": 0
                                }
                        ],
                        "tlv_type": "TLV_TYPE_RECEIVER_LINK_METRIC",
                        "local_al_address": "02:22:07:76:5c:57",
                        "neighbor_al_address": "02:22:07:6d:5e:d7",
                        "receiver_link_metrics_nr": 1,
                        "rx_link_metrics": [
                                {
                                        "local_interface_address": "00:22:07:76:5c:54",
                                        "neighbor_interface_address": "00:22:07:6d:5e:d7",
                                        "intf_type": 0,
                                        "packet_errors": 0,
                                        "packets_received": 19165,
                                        "rssi": 0
                                }
                        ]
                }
        ]
}
```
------------------------------------------------------------------------------------------------------

#### ieee1905 ubus examples


```json
root@iopsys:~# ubus call ieee1905 info
{
        "version": "1905.1a",
        "ieee1905id": "00:22:07:76:5c:54",
        "status": "Enabled",
        "last_change": 107,
        "registrar_freq_band": "802.11 2.4 GHz,802.11 5 GHz",
        "registrar2dot4": "",
        "registrar5": "",
        "registrar60": "",
        "interface_num": 3,
        "interfaces": [
                "wl0",
                "wl1",
                "br-lan"
        ]
}
root@iopsys:~#
```

```json
root@iopsys:~# ubus call ieee1905 interfaces
{
        "interface_nr": 3,
        "names": [
                "wl0",
                "wl1",
                "br-lan"
        ]
}
```

```json
root@iopsys:~# ubus call ieee1905 neighbors
{
        "neighbors_nr": 1,
        "neighbors": [
                "00:22:07:9f:b7:fc"
        ]
}
root@iopsys:~#
```


------------------------------------------------------------------------------------------------------

#### ieee1905.al.`<interface-name>` ubus examples

`ieee1905d` can have multiple `ieee1905.al.<interface-name>` one for each configured al interface.

* **Get info of individual al interface**
```json
root@iopsys:~# ubus -v call ieee1905.al.br-lan info
{
        "name": "br-lan",
        "mac": "00:22:07:76:5c:54",
        "interface_type": "IEEE 802.3ab",
        "secured": true,
        "pushbutton_status": 2,
        "power_state": "On",
        "neighbour_nr": 2,
        "neighbors": [
                "00:22:07:9f:b7:fc",
                "e8:d8:d1:f0:b5:94"
        ],
        "ipv4_nr": 1,
        "ipv4": [
                {
                        "type": true,
                        "address": "192.168.1.1",
                        "dhcp": "127.1.1.1"
                }
        ],
        "ipv6_nr": 0,
        "ipv6": [

        ],
        "vendor_nr": 0

}
root@iopsys:~# 
```

* **Get list of AL entity reachable via this interface**
```json
root@iopsys:~# ubus -v call ieee1905.al.br-lan neighbors
{
        "neighbors_nr": 1,
        "neighbors": [
                "00:22:07:9f:b7:fc"
        ]
}
root@iopsys:~#
```

* **Get interface link specific information**
```json
root@iopsys:~# ubus -v call ieee1905.al.br-lan link_info
{
        "links": [
                {
                        "ieee1905id": "00:22:07:9f:b7:fc",
                        "interfaceid": "00:22:07:9f:b7:fc",
                        "media_type": "IEEE 802.3ab",
                        "ieee802dot1bridge": true,
                        "packet_errors_tx": 0,
                        "transmitted_packets": 511,
                        "mac_throughput_capacity": 0,
                        "link_availability": 100,
                        "packet_errors_rx": 0,
                        "packets_received": 1606,
                        "phy_rate": 0,
                        "rssi": false
                }
        ]
}
```

* **Get topology from any AL entity in network**

This is a ASYNC command, on invocation ubus reply will have `status` and `mid`, rest of the output will be available on `ieee1905.event` broadcast.
In below example, `ubus listen` is used in background to capture the ubus events/broadcast(s).

```json
root@iopsys:~# ubus listen &
root@iopsys:~# ubus call ieee1905.al.br-lan topology '{"remote_mac":"00:22:07:9f:b7:fc"}'
{
        "mid": 55019,
        "status": true
}

{ "ieee1905.cmdu": {"type":3,"mid":55019,"ingress":"br-lan","source":"00:22:07:9f:b7:fc","tlvs":"0300360022079fb7fc030022079fb7fd01050a0022079fb7fd000234340022079fb7fe01030a0022079fb7fe000006060022079fb7fc00010007000d0022079fb7fc002207765c54801e0011010022079fb7fc0001002207765c540000"} }

root@iopsys:~#
```
## Dependencies

### Build-Time Dependencies

To successfully build ieee1905d, following libraries are needed:

| Dependency   |                    Link                         |    License        |
| ------------ | ----------------------------------------------- | ----------------- |
| libuci       | https://git.openwrt.org/project/uci.git         | LGPL 2.1          |
| libubox      | https://git.openwrt.org/project/libubox.git     | BSD               |
| libubus      | https://git.openwrt.org/project/ubus.git        | LGPL 2.1          |
| libjson-c    | https://s3.amazonaws.com/json-c_releases        | MIT               |
| easy-soc-libs| https://dev.iopsys.eu/iopsys/easy-soc-libs.git  | GPLv2             |
| libpcap      | http://www.tcpdump.org/release/                 | BSD-3-Clause      |
| libcrypto    | http://www.openssl.org/                         | Apache License 2.0|


### Run-Time Dependencies

In order to run the ieee1905d, following dependencies are needed to be running/available before ieee1905d.

| Dependency |                   Link                   | License  |
| ---------- | ---------------------------------------- | -------- |
| ubusd      | https://git.openwrt.org/project/ubus.git | LGPL 2.1 |

Below ubus objects and methods invoked at runtime

|   Ubus object  |   Ubus method |
| -------------- | ------------- |
| uci            | reload_config |
| network.device | status        |
| wifi.radio.    |     -         |

Below ubus events monitored at runtime

|   Ubus event   |    Used for                |
| -------------- | -------------------------- |
| button.WPS     | Push button notifications  |
| wifi.sta       | Notification change event  |

### Limitation and known issues

- ALME has limited support over ubus only
- Supports only wireless and ethernet interfaces
