# ieee1905 Schema

```
https://www.iopsys.eu/usp.raw.json
```

| Custom Properties | Additional Properties |
| ----------------- | --------------------- |
| Forbidden         | Forbidden             |

# ieee1905

| List of Methods                   |
| --------------------------------- |
| [info](#info)                     | Method | ieee1905 (this schema) |
| [link_info](#link_info)           | Method | ieee1905 (this schema) |
| [neighbors](#neighbors)           | Method | ieee1905 (this schema) |
| [query_topology](#query_topology) | Method | ieee1905 (this schema) |

## info

### AL entity interface info

`info`

- type: `Method`

### info Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `input`  | object | Optional |
| `output` | object | Optional |

#### input

`input`

- is optional
- type: `object`

##### input Type

`object` with following properties:

| Property | Type | Required |
| -------- | ---- | -------- |
| None     | None | None     |

### Ubus CLI Example

```
ubus call ieee1905 info {}
```

### JSONRPC Example

```json
{ "jsonrpc": "2.0", "id": 0, "method": "call", "params": ["<SID>", "ieee1905", "info", {}] }
```

#### output

`output`

- is optional
- type: `object`

##### output Type

`object` with following properties:

| Property            | Type    | Required |
| ------------------- | ------- | -------- |
| `interface_type`    | string  | Optional |
| `ipv4`              | array   | Optional |
| `ipv4_nr`           | integer | Optional |
| `ipv6`              | array   | Optional |
| `ipv6_nr`           | integer | Optional |
| `mac`               | string  | Optional |
| `name`              | string  | Optional |
| `neighbors`         | array   | Optional |
| `neighbour_nr`      | integer | Optional |
| `power_state`       | string  | Optional |
| `pushbutton_status` | integer | Optional |
| `secured`           | boolean | Optional |

#### interface_type

Linux network interface type

`interface_type`

- is optional
- type: reference

##### interface_type Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=%5EIEEE%20802%5C.(3u%7C3ab%7C11b%7C11g%7C11a%7C11n%202.4%7C11n%205.0%7C11ac%7C11ad%7C11af)>)):

```regex
^IEEE 802\.(3u|3ab|11b|11g|11a|11n 2.4|11n 5.0|11ac|11ad|11af)
```

#### ipv4

`ipv4`

- is optional
- type: `object[]`

##### ipv4 Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property  | Type    | Required |
| --------- | ------- | -------- |
| `address` | string  | Optional |
| `dhcp`    | string  | Optional |
| `type`    | boolean | Optional |

#### address

IPv4 Address

`address`

- is optional
- type: reference

##### address Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(%5B0-255%5D%5C.)%7B3%7D%5B0-255%5D>)):

```regex
([0-255]\.){3}[0-255]
```

#### dhcp

IPv4 Address

`dhcp`

- is optional
- type: reference

##### dhcp Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(%5B0-255%5D%5C.)%7B3%7D%5B0-255%5D>)):

```regex
([0-255]\.){3}[0-255]
```

#### type

`type`

- is optional
- type: `boolean`

##### type Type

`boolean`

#### ipv4_nr

`ipv4_nr`

- is optional
- type: `integer`

##### ipv4_nr Type

`integer`

- minimum value: `0`

#### ipv6

`ipv6`

- is optional
- type: `array`

##### ipv6 Type

Array type: `array`

All items must be of the type: Unknown type ``.

```json
{
  "type": "array",
  "items": {
    "simpletype": "complex"
  },
  "simpletype": "`array`"
}
```

#### ipv6_nr

`ipv6_nr`

- is optional
- type: `integer`

##### ipv6_nr Type

`integer`

- minimum value: `0`

#### mac

mac address in string format

`mac`

- is optional
- type: reference

##### mac Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### name

Linux network interface name

`name`

- is optional
- type: reference

##### name Type

`string`

- minimum length: 2 characters
- maximum length: 256 characters All instances must conform to this regular expression

```regex
([a-z]+|br-){1}[a-z]+[0-9]
```

- test example: [eth0](<https://regexr.com/?expression=(%5Ba-z%5D%2B%7Cbr-)%7B1%7D%5Ba-z%5D%2B%5B0-9%5D&text=eth0>)
- test example: [br-lan](<https://regexr.com/?expression=(%5Ba-z%5D%2B%7Cbr-)%7B1%7D%5Ba-z%5D%2B%5B0-9%5D&text=br-lan>)

##### name Examples

```json
eth0
```

```json
br - lan
```

#### neighbors

`neighbors`

- is optional
- type: reference

##### neighbors Type

Array type: reference

All items must be of the type: `string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

mac address in string format

#### neighbour_nr

`neighbour_nr`

- is optional
- type: `integer`

##### neighbour_nr Type

`integer`

- minimum value: `0`

#### power_state

`power_state`

- is optional
- type: `string`

##### power_state Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(On%7COff)>)):

```regex
(On|Off)
```

#### pushbutton_status

`pushbutton_status`

- is optional
- type: `integer`

##### pushbutton_status Type

`integer`

#### secured

`secured`

- is optional
- type: `boolean`

##### secured Type

`boolean`

### Output Example

```json
{
  "name": "br-cmp6",
  "mac": "cF:4b:23:8F:FF:Cb",
  "interface_type": "IEEE 802.11b",
  "secured": true,
  "pushbutton_status": 2,
  "power_state": "On",
  "neighbour_nr": 36071730,
  "neighbors": ["9A:F4:5F:5b:1F:C9", "4F:c1:44:10:b5:25", "cC:bf:d5:04:04:Fb", "43:E4:3d:1C:68:1d"],
  "ipv4_nr": 71946620,
  "ipv4": [
    { "type": false, "address": "1.0.5.2", "dhcp": "5.2.2.5" },
    { "type": false, "address": "1.5.5.5", "dhcp": "2.1.2.2" },
    { "type": true, "address": "0.5.1.1", "dhcp": "0.1.0.2" },
    { "type": true, "address": "5.2.1.2", "dhcp": "5.2.0.1" },
    { "type": false, "address": "5.5.1.5", "dhcp": "2.5.5.5" }
  ],
  "ipv6_nr": 76673228,
  "ipv6": [{}]
}
```

## link_info

### List link specific info

Link specific information for the AL neighbours reachable via this interface

`link_info`

- type: `Method`

### link_info Type

`object` with following properties:

| Property | Type   | Required     |
| -------- | ------ | ------------ |
| `input`  | object | Optional     |
| `output` | object | **Required** |

#### input

`input`

- is optional
- type: `object`

##### input Type

`object` with following properties:

| Property | Type | Required |
| -------- | ---- | -------- |
| None     | None | None     |

### Ubus CLI Example

```
ubus call ieee1905 link_info {}
```

### JSONRPC Example

```json
{ "jsonrpc": "2.0", "id": 0, "method": "call", "params": ["<SID>", "ieee1905", "link_info", {}] }
```

#### output

`output`

- is **required**
- type: `object`

##### output Type

`object` with following properties:

| Property | Type  | Required |
| -------- | ----- | -------- |
| `links`  | array | Optional |

#### links

`links`

- is optional
- type: `object[]`

##### links Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property                  | Type    | Required |
| ------------------------- | ------- | -------- |
| `ieee1905id`              | string  | Optional |
| `ieee802dot1bridge`       | boolean | Optional |
| `interfaceid`             | string  | Optional |
| `link_availability`       | integer | Optional |
| `mac_throughput_capacity` | integer | Optional |
| `media_type`              | string  | Optional |
| `packet_errors_rx`        | integer | Optional |
| `packet_errors_tx`        | integer | Optional |
| `packets_received`        | integer | Optional |
| `phy_rate`                | integer | Optional |
| `rssi`                    | integer | Optional |
| `transmitted_packers`     | integer | Optional |

#### ieee1905id

mac address in string format

`ieee1905id`

- is optional
- type: reference

##### ieee1905id Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### ieee802dot1bridge

`ieee802dot1bridge`

- is optional
- type: `boolean`

##### ieee802dot1bridge Type

`boolean`

#### interfaceid

mac address in string format

`interfaceid`

- is optional
- type: reference

##### interfaceid Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### link_availability

`link_availability`

- is optional
- type: `integer`

##### link_availability Type

`integer`

- minimum value: `0`
- maximum value: `100`

#### mac_throughput_capacity

`mac_throughput_capacity`

- is optional
- type: `integer`

##### mac_throughput_capacity Type

`integer`

- minimum value: `0`

#### media_type

Linux network interface type

`media_type`

- is optional
- type: reference

##### media_type Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=%5EIEEE%20802%5C.(3u%7C3ab%7C11b%7C11g%7C11a%7C11n%202.4%7C11n%205.0%7C11ac%7C11ad%7C11af)>)):

```regex
^IEEE 802\.(3u|3ab|11b|11g|11a|11n 2.4|11n 5.0|11ac|11ad|11af)
```

#### packet_errors_rx

`packet_errors_rx`

- is optional
- type: `integer`

##### packet_errors_rx Type

`integer`

- minimum value: `0`

#### packet_errors_tx

`packet_errors_tx`

- is optional
- type: `integer`

##### packet_errors_tx Type

`integer`

- minimum value: `0`

#### packets_received

`packets_received`

- is optional
- type: `integer`

##### packets_received Type

`integer`

- minimum value: `0`

#### phy_rate

`phy_rate`

- is optional
- type: `integer`

##### phy_rate Type

`integer`

- minimum value: `0`

#### rssi

`rssi`

- is optional
- type: `integer`

##### rssi Type

`integer`

- minimum value: `-128`
- maximum value: `128`

#### transmitted_packers

`transmitted_packers`

- is optional
- type: `integer`

##### transmitted_packers Type

`integer`

- minimum value: `0`

### Output Example

```json
{
  "links": [
    {
      "ieee1905id": "eD:9d:9f:C4:08:BE",
      "interfaceid": "8B:3F:89:De:f6:AE",
      "media_type": "IEEE 802.11n 5[0",
      "ieee802dot1bridge": true,
      "packet_errors_tx": 50865976,
      "transmitted_packers": 69822777,
      "mac_throughput_capacity": 29362421,
      "link_availability": 99,
      "packet_errors_rx": 4012928,
      "packets_received": 31543820,
      "phy_rate": 39684929,
      "rssi": -39
    },
    {
      "ieee1905id": "6B:eA:FE:fe:Cd:BD",
      "interfaceid": "b7:9d:fa:CC:19:27",
      "media_type": "IEEE 802.11n 5D0",
      "ieee802dot1bridge": false,
      "packet_errors_tx": 88225162,
      "transmitted_packers": 29436660,
      "mac_throughput_capacity": 33937611,
      "link_availability": 56,
      "packet_errors_rx": 24138448,
      "packets_received": 2142743,
      "phy_rate": 34797239,
      "rssi": -122
    },
    {
      "ieee1905id": "e4:3A:90:b5:8a:38",
      "interfaceid": "E7:6d:26:a1:A4:bb",
      "media_type": "IEEE 802.11n 5J0",
      "ieee802dot1bridge": false,
      "packet_errors_tx": 27332228,
      "transmitted_packers": 36792928,
      "mac_throughput_capacity": 22516819,
      "link_availability": 9,
      "packet_errors_rx": 38838975,
      "packets_received": 1845852,
      "phy_rate": 21241637,
      "rssi": 96
    }
  ]
}
```

## neighbors

### Get list of neighbors reachable via this interface

`neighbors`

- type: `Method`

### neighbors Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `input`  | object | Optional |
| `output` | object | Optional |

#### input

`input`

- is optional
- type: `object`

##### input Type

`object` with following properties:

| Property | Type | Required |
| -------- | ---- | -------- |
| None     | None | None     |

### Ubus CLI Example

```
ubus call ieee1905 neighbors {}
```

### JSONRPC Example

```json
{ "jsonrpc": "2.0", "id": 0, "method": "call", "params": ["<SID>", "ieee1905", "neighbors", {}] }
```

#### output

`output`

- is optional
- type: `object`

##### output Type

`object` with following properties:

| Property       | Type    | Required |
| -------------- | ------- | -------- |
| `neighbors`    | array   | Optional |
| `neighbors_nr` | integer | Optional |

#### neighbors

`neighbors`

- is optional
- type: reference

##### neighbors Type

Array type: reference

All items must be of the type: `string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

mac address in string format

#### neighbors_nr

`neighbors_nr`

- is optional
- type: `integer`

##### neighbors_nr Type

`integer`

- minimum value: `1`
- maximum value: `255`

### Output Example

```json
{
  "neighbors_nr": 234,
  "neighbors": [
    "Dd:03:d6:16:d1:A9",
    "dD:6F:C9:D1:Fd:dF",
    "cA:8E:F2:4B:E3:E8",
    "dD:96:5f:F1:2F:E5",
    "96:7B:df:29:Dd:7f"
  ]
}
```

## query_topology

### Send topology query to self or remote AL entity

`query_topology`

- type: `Method`

### query_topology Type

`object` with following properties:

| Property | Type   | Required     |
| -------- | ------ | ------------ |
| `input`  | object | **Required** |
| `output` | object | **Required** |

#### input

`input`

- is **required**
- type: `object`

##### input Type

`object` with following properties:

| Property      | Type   | Required     |
| ------------- | ------ | ------------ |
| `dst_macaddr` | string | **Required** |

#### dst_macaddr

mac address in string format

`dst_macaddr`

- is **required**
- type: reference

##### dst_macaddr Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

### Ubus CLI Example

```
ubus call ieee1905 query_topology {"dst_macaddr":"A6:7d:2c:10:7d:9a"}
```

### JSONRPC Example

```json
{
  "jsonrpc": "2.0",
  "id": 0,
  "method": "call",
  "params": ["<SID>", "ieee1905", "query_topology", { "dst_macaddr": "A6:7d:2c:10:7d:9a" }]
}
```

#### output

`output`

- is **required**
- type: `object`

##### output Type

`object` with following properties:

| Property | Type    | Required     |
| -------- | ------- | ------------ |
| `mid`    | integer | **Required** |
| `status` | boolean | **Required** |

#### mid

CMDU message identifier

`mid`

- is **required**
- type: reference

##### mid Type

`integer`

- minimum value: `0`
- maximum value: `65535`

#### status

`status`

- is **required**
- type: `boolean`

##### status Type

`boolean`

### Output Example

```json
{ "mid": 42780, "status": false }
```
