# ieee1905 Schema

```
https://www.iopsys.eu/usp.raw.json
```

| Custom Properties | Additional Properties |
| ----------------- | --------------------- |
| Forbidden         | Forbidden             |

# ieee1905

| List of Methods                   |
| --------------------------------- |
| [info](#info)                     | Method | ieee1905 (this schema) |
| [interfaces](#interfaces)         | Method | ieee1905 (this schema) |
| [neighbors](#neighbors)           | Method | ieee1905 (this schema) |
| [query_topology](#query_topology) | Method | ieee1905 (this schema) |
| [send_query](#send_query)         | Method | ieee1905 (this schema) |

## info

### AL entity info

`info`

- type: `Method`

### info Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `input`  | object | Optional |
| `output` | object | Optional |

#### input

`input`

- is optional
- type: `object`

##### input Type

`object` with following properties:

| Property | Type | Required |
| -------- | ---- | -------- |
| None     | None | None     |

### Ubus CLI Example

```
ubus call ieee1905 info {}
```

### JSONRPC Example

```json
{ "jsonrpc": "2.0", "id": 0, "method": "call", "params": ["<SID>", "ieee1905", "info", {}] }
```

#### output

`output`

- is optional
- type: `object`

##### output Type

`object` with following properties:

| Property              | Type    | Required |
| --------------------- | ------- | -------- |
| `ieee1905id`          | string  | Optional |
| `interface_num`       | integer | Optional |
| `interfaces`          | array   | Optional |
| `last_change`         | integer | Optional |
| `registrar2dot4`      | string  | Optional |
| `registrar5`          | string  | Optional |
| `registrar60`         | string  | Optional |
| `registrar_freq_band` | string  | Optional |
| `status`              | string  | Optional |
| `version`             | string  | Optional |

#### ieee1905id

mac address in string format

`ieee1905id`

- is optional
- type: reference

##### ieee1905id Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### interface_num

`interface_num`

- is optional
- type: `integer`

##### interface_num Type

`integer`

- minimum value: `0`

#### interfaces

`interfaces`

- is optional
- type: reference

##### interfaces Type

Array type: reference

All items must be of the type: `string`

- minimum length: 2 characters
- maximum length: 256 characters All instances must conform to this regular expression

```regex
[a-z-]+[0-9]
```

- test example: [eth0](https://regexr.com/?expression=%5Ba-z-%5D%2B%5B0-9%5D&text=eth0)
- test example: [br-lan](https://regexr.com/?expression=%5Ba-z-%5D%2B%5B0-9%5D&text=br-lan)

Linux network interface name

#### last_change

`last_change`

- is optional
- type: `integer`

##### last_change Type

`integer`

- minimum value: `0`

#### registrar2dot4

mac address in string format

`registrar2dot4`

- is optional
- type: reference

##### registrar2dot4 Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### registrar5

mac address in string format

`registrar5`

- is optional
- type: reference

##### registrar5 Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### registrar60

mac address in string format

`registrar60`

- is optional
- type: reference

##### registrar60 Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### registrar_freq_band

mac address in string format

`registrar_freq_band`

- is optional
- type: reference

##### registrar_freq_band Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### status

`status`

- is optional
- type: `string`

##### status Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(Enabled%7CDisabled)>)):

```regex
(Enabled|Disabled)
```

#### version

`version`

- is optional
- type: `string`

##### version Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(1905%5C.1a%7C1905)>)):

```regex
(1905\.1a|1905)
```

### Output Example

```json
{
  "version": "1905.1a",
  "ieee1905id": "98:B1:ce:0b:11:BC",
  "status": "Enabled",
  "last_change": 26904395,
  "registrar_freq_band": "Fc:6C:79:51:D2:18",
  "registrar2dot4": "0C:bC:fc:d6:F5:2f",
  "registrar5": "BE:A8:dc:16:bA:bB",
  "registrar60": "Db:eC:9B:35:F9:a3",
  "interface_num": 75931087,
  "interfaces": ["ope-9", "olo-p9"]
}
```

## interfaces

### List down supported usp operate commands

Commands will be shown in schema format

`interfaces`

- type: `Method`

### interfaces Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `input`  | object | Optional |
| `output` | object | Optional |

#### input

`input`

- is optional
- type: `object`

##### input Type

`object` with following properties:

| Property | Type | Required |
| -------- | ---- | -------- |
| None     | None | None     |

### Ubus CLI Example

```
ubus call ieee1905 interfaces {}
```

### JSONRPC Example

```json
{ "jsonrpc": "2.0", "id": 0, "method": "call", "params": ["<SID>", "ieee1905", "interfaces", {}] }
```

#### output

`output`

- is optional
- type: `object`

##### output Type

`object` with following properties:

| Property       | Type    | Required |
| -------------- | ------- | -------- |
| `interface_nr` | integer | Optional |
| `names`        | array   | Optional |

#### interface_nr

`interface_nr`

- is optional
- type: `integer`

##### interface_nr Type

`integer`

- minimum value: `1`

#### names

`names`

- is optional
- type: reference

##### names Type

Array type: reference

All items must be of the type: `string`

- minimum length: 2 characters
- maximum length: 256 characters All instances must conform to this regular expression

```regex
[a-z-]+[0-9]
```

- test example: [eth0](https://regexr.com/?expression=%5Ba-z-%5D%2B%5B0-9%5D&text=eth0)
- test example: [br-lan](https://regexr.com/?expression=%5Ba-z-%5D%2B%5B0-9%5D&text=br-lan)

Linux network interface name

### Output Example

```json
{ "interface_nr": 52887321, "names": ["eo-kjt3", "jgloz4", "jkpo-c8"] }
```

## neighbors

### Get multiple object names

Query multiple object names at once

`neighbors`

- type: `Method`

### neighbors Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `input`  | object | Optional |
| `output` | object | Optional |

#### input

`input`

- is optional
- type: `object`

##### input Type

`object` with following properties:

| Property | Type | Required |
| -------- | ---- | -------- |
| None     | None | None     |

### Ubus CLI Example

```
ubus call ieee1905 neighbors {}
```

### JSONRPC Example

```json
{ "jsonrpc": "2.0", "id": 0, "method": "call", "params": ["<SID>", "ieee1905", "neighbors", {}] }
```

#### output

`output`

- is optional
- type: `object`

##### output Type

`object` with following properties:

| Property       | Type    | Required |
| -------------- | ------- | -------- |
| `neighbors`    | array   | Optional |
| `neighbors_nr` | integer | Optional |

#### neighbors

`neighbors`

- is optional
- type: reference

##### neighbors Type

Array type: reference

All items must be of the type: `string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

mac address in string format

#### neighbors_nr

`neighbors_nr`

- is optional
- type: `integer`

##### neighbors_nr Type

`integer`

- minimum value: `1`
- maximum value: `255`

### Output Example

```json
{ "neighbors_nr": 232, "neighbors": ["15:ea:B3:D2:9e:A0", "91:1B:FA:cf:12:80"] }
```

## query_topology

### Send topology query to self or remote node

`query_topology`

- type: `Method`

### query_topology Type

`object` with following properties:

| Property | Type   | Required     |
| -------- | ------ | ------------ |
| `input`  | object | **Required** |
| `output` | object | **Required** |

#### input

`input`

- is **required**
- type: `object`

##### input Type

`object` with following properties:

| Property      | Type   | Required     |
| ------------- | ------ | ------------ |
| `dst_macaddr` | string | **Required** |

#### dst_macaddr

mac address in string format

`dst_macaddr`

- is **required**
- type: reference

##### dst_macaddr Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

### Ubus CLI Example

```
ubus call ieee1905 query_topology {"dst_macaddr":"32:ce:Ee:Cc:CA:E8"}
```

### JSONRPC Example

```json
{
  "jsonrpc": "2.0",
  "id": 0,
  "method": "call",
  "params": ["<SID>", "ieee1905", "query_topology", { "dst_macaddr": "32:ce:Ee:Cc:CA:E8" }]
}
```

#### output

`output`

- is **required**
- type: `object`

##### output Type

`object` with following properties:

| Property | Type    | Required     |
| -------- | ------- | ------------ |
| `mid`    | integer | **Required** |
| `status` | string  | **Required** |

#### mid

CMDU message identifier

`mid`

- is **required**
- type: reference

##### mid Type

`integer`

- minimum value: `0`
- maximum value: `65535`

#### status

`status`

- is **required**
- type: reference

##### status Type

`string`

All instances must conform to this regular expression (test examples [here](<https://regexr.com/?expression=(0%7C1)>)):

```regex
(0|1)
```

### Output Example

```json
{ "mid": 17886, "status": "0" }
```

## send_query

### Send CMDU queries to AL nodes

`send_query`

- type: `Method`

### send_query Type

`object` with following properties:

| Property | Type   | Required     |
| -------- | ------ | ------------ |
| `input`  | object | **Required** |
| `output` | object | **Required** |

#### input

`input`

- is **required**
- type: `object`

##### input Type

`object` with following properties:

| Property      | Type    | Required     |
| ------------- | ------- | ------------ |
| `data`        | string  | **Required** |
| `dst_macaddr` | string  | **Required** |
| `egress`      | string  | **Required** |
| `type`        | integer | **Required** |

#### data

`data`

- is **required**
- type: reference

##### data Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%5B0-9a-fA-F%5D)%2B>)):

```regex
([0-9a-fA-F][0-9a-fA-F])+
```

#### dst_macaddr

mac address in string format

`dst_macaddr`

- is **required**
- type: reference

##### dst_macaddr Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### egress

Linux network interface name

`egress`

- is **required**
- type: reference

##### egress Type

`string`

- minimum length: 2 characters
- maximum length: 256 characters All instances must conform to this regular expression

```regex
[a-z-]+[0-9]
```

- test example: [eth0](https://regexr.com/?expression=%5Ba-z-%5D%2B%5B0-9%5D&text=eth0)
- test example: [br-lan](https://regexr.com/?expression=%5Ba-z-%5D%2B%5B0-9%5D&text=br-lan)

##### egress Examples

```json
eth0
```

```json
br - lan
```

#### type

Cmdu message type

`type`

- is **required**
- type: reference

##### type Type

`integer`

### Ubus CLI Example

```
ubus call ieee1905 send_query {"type":5,"egress":"zqgqfy6","dst_macaddr":"78:c6:9D:4F:cB:B1","data":"9Ee9c21441"}
```

### JSONRPC Example

```json
{
  "jsonrpc": "2.0",
  "id": 0,
  "method": "call",
  "params": [
    "<SID>",
    "ieee1905",
    "send_query",
    { "type": 5, "egress": "zqgqfy6", "dst_macaddr": "78:c6:9D:4F:cB:B1", "data": "9Ee9c21441" }
  ]
}
```

#### output

`output`

- is **required**
- type: `object`

##### output Type

`object` with following properties:

| Property | Type    | Required     |
| -------- | ------- | ------------ |
| `mid`    | integer | **Required** |
| `status` | string  | **Required** |

#### mid

CMDU message identifier

`mid`

- is **required**
- type: reference

##### mid Type

`integer`

- minimum value: `0`
- maximum value: `65535`

#### status

`status`

- is **required**
- type: reference

##### status Type

`string`

All instances must conform to this regular expression (test examples [here](<https://regexr.com/?expression=(0%7C1)>)):

```regex
(0|1)
```

### Output Example

```json
{ "mid": 29209, "status": "0" }
```
