#!/bin/bash
OUT_PATH=./test/output

# output metrics used for validation in this file is aligned with pcap(s)
# used to simulate neighbor

function verify_file()
{
	diff -q ${OUT_PATH}/${1} ${2} >/dev/null 2>&1

	if [ "$?" -eq 0 ]; then
		echo "PASS"
	else
		echo "Output differs"
		cat ${2}
		exit 1
	fi
}

function verify_output()
{
	grep -wq "${1}" /tmp/t.log
	if [ "$?" -eq 0 ]; then
		echo "PASS"
	else
		echo "Output differs"
		cat /tmp/t.log
		exit 1
	fi
}

function verify_info()
{
	echo "Verify ieee1905 info"
	ubus call ieee1905.al.eth0 info >/tmp/t.log

	verify_output "\"name\": \"eth0\","
}

function verify_neighbors()
{
	echo "Verify ieee1905 neighbors info"
	ubus call ieee1905.al.eth0 neighbors >/tmp/t.log

	verify_file neighbors.data /tmp/t.log
}

function verify_link()
{
	echo "Verify ieee1905 link info"
	ubus call ieee1905.al.eth0 link_info >/tmp/t.log

	verify_output "00:22:07:6f:70:e2"
}

## Call tests here
verify_info
verify_neighbors
verify_link
