/*
 * get_tlvs.h: Get TLV related functions header
 *
 * Author: Vivek Dutta <vivek.dutta@iopsys.eu>
 *
 * Copyright (C) 2020, IOPSYS Software Solutions AB
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * Subject to the terms and conditions of this license, each copyright
 * holder and contributor hereby grants to those receiving rights under
 * this license a perpetual, worldwide, non-exclusive, no-charge,
 * royalty-free, irrevocable (except for failure to satisfy the
 * conditions of this license) patent license to make, have made, use,
 * offer to sell, sell, import, and otherwise transfer this software,
 * where such license applies only to those patent claims, already
 * acquired or hereafter acquired, licensable by such copyright holder or
 * contributor that are necessarily infringed by:
 * (a) their Contribution(s) (the licensed copyrights of copyright holders
 *     and non-copyrightable additions of contributors, in source or binary
 *     form) alone; or
 *
 * (b) combination of their Contribution(s) with the work of authorship to
 *     which such Contribution(s) was added by such copyright holder or
 *     contributor, if, at the time the Contribution is added, such addition
 *     causes such combination to be necessarily infringed. The patent
 *     license shall not apply to any other combinations which include the
 *     Contribution.
 *
 * Except as expressly stated above, no rights or licenses from any
 * copyright holder or contributor is granted under this license, whether
 * expressly, by implication, estoppel or otherwise.
 *
 * DISCLAIMER
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef _GET_TLVS_H_
#define _GET_TLVS_H_

#include "utils.h"
#include "1905_tlvs.h"

// End of message TLV associated structures ("Section 6.4.1")
bool get_endOfMessageTLV(struct endOfMessageTLV *ret);

// Vendor specific TLV associated structures ("Section 6.4.2")
bool get_vendorSpecificTLV(struct vendorSpecificTLV *ret);

// AL MAC address type TLV associated structures ("Section 6.4.3")
bool get_alMacAddressTypeTLV(struct alMacAddressTypeTLV *ret);

// MAC address type TLV associated structures ("Section 6.4.4")
bool get_macAddressTypeTLV(struct macAddressTypeTLV *ret, char *nr);

// Device information type TLV associated structures ("Section 6.4.5")
bool get_deviceInformationTypeTLV(struct deviceInformationTypeTLV *ret);

// Device bridging capability TLV associated structures ("Section 6.4.6")
bool get_deviceBridgingCapabilityTLV(struct deviceBridgingCapabilityTLV *ret);

// Non-1905 neighbor device list TLV associated structures ("Section 6.4.8")
bool get_non1905NeighborDeviceListTLV(struct non1905NeighborDeviceListTLV *ret, char *nr);

// Neighbor device TLV associated structures ("Section 6.4.9")
bool get_neighborDeviceListTLV(struct neighborDeviceListTLV *ret, char *nr);

// Link metric query TLV associated structures ("Section 6.4.10")
bool get_linkMetricQueryTLV(struct linkMetricQueryTLV *ret);
bool get_secific_linkMetricQueryTLV(struct linkMetricQueryTLV *tlv, INT8U *specific_neighbor, INT8U metrix_type);

// Transmitter link metric TLV associated structures ("Section 6.4.11")
bool get_transmitterLinkMetricTLV(struct transmitterLinkMetricTLV *ret);

// Receiver link metric TLV associated structures ("Section 6.4.12")
bool get_receiverLinkMetricTLV(struct receiverLinkMetricTLV *ret);

// Link metric result code TLV associated structures ("Section 6.4.13")
bool get_linkMetricResultCodeTLV(struct linkMetricResultCodeTLV *ret);

// Searched role TLV associated structures ("Section 6.4.14")
bool get_searchedRoleTLV(struct searchedRoleTLV *ret);

// Autoconfig frequency band TLV associated structures ("Section 6.4.15")
bool get_autoconfigFreqBandTLV(struct autoconfigFreqBandTLV *ret, INT8U freq_band);

// Supported role TLV associated structures ("Section 6.4.16")
bool get_supportedRoleTLV(struct supportedRoleTLV *ret);

// Supported frequency band TLV associated structures ("Section 6.4.17")
bool get_supportedFreqBandTLV(struct supportedFreqBandTLV *ret, INT8U freq_band);

// Supported frequency band TLV associated structures ("Section 6.4.18")
bool get_wscTLV(struct wscTLV *ret, INT8U *wsc_frame, INT16U wsc_frame_size);

// Push button event notification TLV associated structures ("Section 6.4.19")
bool get_pushButtonEventNotificationTLV(struct pushButtonEventNotificationTLV *ret);

// Push button join notification TLV associated structures ("Section 6.4.20")
bool get_pushButtonJoinNotificationTLV(struct pushButtonJoinNotificationTLV *tlv, INT8U *original_al_mac_address,
				       INT16U original_mid, INT8U *local_mac_address, INT8U *new_mac_address);

// Generic PHY device information TLV associated structures ("Section 6.4.21")
bool get_genericPhyDeviceInformationTypeTLV(struct genericPhyDeviceInformationTypeTLV *ret);

// Device identification type TLV associated structures ("Section 6.4.22")
bool get_deviceIdentificationTypeTLV(struct deviceIdentificationTypeTLV *ret);

// Control URL type TLV associated structures ("Section 6.4.23")
bool get_controlUrlTypeTLV(struct controlUrlTypeTLV *ret);

// IPv4 type TLV associated structures ("Section 6.4.24")
bool get_ipv4TypeTLV(struct ipv4TypeTLV *ret);

// IPv6 type TLV associated structures ("Section 6.4.25")
bool get_ipv6TypeTLV(struct ipv6TypeTLV *ret);

// Push button generic PHY event notification TLV structures ("Section 6.4.26")
bool get_pushButtonGenericPhyEventNotificationTLV(struct pushButtonGenericPhyEventNotificationTLV *ret);

// Profile version TLV associated structures ("Section 6.4.27")
bool get_x1905ProfileVersionTLV(struct x1905ProfileVersionTLV *ret);

// Power off interface TLV associated structures ("Section 6.4.28")
bool get_powerOffInterfaceTLV(struct powerOffInterfaceTLV *ret);

// Interface power change information TLV structures ("Section 6.4.29")
bool get_interfacePowerChangeInformationTLV(struct interfacePowerChangeInformationTLV *ret);

// Interface power change status TLV associated structures ("Section 6.4.29")
bool get_interfacePowerChangeStatusTLV(struct interfacePowerChangeStatusTLV *ret);

// L2 neighbor device TLV associated structures ("Section 6.4.31")
bool get_l2NeighborDeviceTLV(struct l2NeighborDeviceTLV *ret);

#endif
