/*
 * plugin_mngr.h: Plugin manager to support map-plugin
 *
 * Author: Vivek Dutta <vivek.dutta@iopsys.eu>
 *
 * Copyright (C) 2020, IOPSYS Software Solutions AB
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * Subject to the terms and conditions of this license, each copyright
 * holder and contributor hereby grants to those receiving rights under
 * this license a perpetual, worldwide, non-exclusive, no-charge,
 * royalty-free, irrevocable (except for failure to satisfy the
 * conditions of this license) patent license to make, have made, use,
 * offer to sell, sell, import, and otherwise transfer this software,
 * where such license applies only to those patent claims, already
 * acquired or hereafter acquired, licensable by such copyright holder or
 * contributor that are necessarily infringed by:
 * (a) their Contribution(s) (the licensed copyrights of copyright holders
 *     and non-copyrightable additions of contributors, in source or binary
 *     form) alone; or
 *
 * (b) combination of their Contribution(s) with the work of authorship to
 *     which such Contribution(s) was added by such copyright holder or
 *     contributor, if, at the time the Contribution is added, such addition
 *     causes such combination to be necessarily infringed. The patent
 *     license shall not apply to any other combinations which include the
 *     Contribution.
 *
 * Except as expressly stated above, no rights or licenses from any
 * copyright holder or contributor is granted under this license, whether
 * expressly, by implication, estoppel or otherwise.
 *
 * DISCLAIMER
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef _PLUGIN_MNGR_H_
#define _PLUGIN_MNGR_H_

#include "utils.h"
#include "1905_cmdus.h"
#include "plugin.h"
#include <libubus.h>

enum map_role {
	MAP_ROLE_AGENT = 0x1,
	MAP_ROLE_CONTROLLER = 0x2
};

enum map_profile {
	MAP_PROFILE_1 = 0x1,
	MAP_PROFILE_2 = 0x2,
};

bool installPlugin(char *path, char *libname);
int plugin_map_init(struct ubus_context *ctx);
bool plugin_process(struct cmdu_stream *c_stream, INT8U *receiving_interface_addr, INT8U *origin);
int plugin_cleanup(struct ubus_context *ctx);
void removePlugin(void);

INT8U get_map_registered_mode(void);
INT8U get_map_profile_type(void);

#endif
