/*
 * utils_uci.h: Common json utility functions
 *
 * Author: Vivek Dutta <vivek.dutta@iopsys.eu>
 *
 * Copyright (C) 2019, IOPSYS Software Solutions AB
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * Subject to the terms and conditions of this license, each copyright
 * holder and contributor hereby grants to those receiving rights under
 * this license a perpetual, worldwide, non-exclusive, no-charge,
 * royalty-free, irrevocable (except for failure to satisfy the
 * conditions of this license) patent license to make, have made, use,
 * offer to sell, sell, import, and otherwise transfer this software,
 * where such license applies only to those patent claims, already
 * acquired or hereafter acquired, licensable by such copyright holder or
 * contributor that are necessarily infringed by:
 * (a) their Contribution(s) (the licensed copyrights of copyright holders
 *     and non-copyrightable additions of contributors, in source or binary
 *     form) alone; or
 *
 * (b) combination of their Contribution(s) with the work of authorship to
 *     which such Contribution(s) was added by such copyright holder or
 *     contributor, if, at the time the Contribution is added, such addition
 *     causes such combination to be necessarily infringed. The patent
 *     license shall not apply to any other combinations which include the
 *     Contribution.
 *
 * Except as expressly stated above, no rights or licenses from any
 * copyright holder or contributor is granted under this license, whether
 * expressly, by implication, estoppel or otherwise.
 *
 * DISCLAIMER
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef _UTILS_UCI_H_
#define _UTILS_UCI_H_
#define UCI_WLAN_IFACE "wifi-iface"
#define UCI_WIRELESS "wireless"
#define UCI_IEEE1905 "ieee1905"

bool uci_get_option(const char *pkg_name, const char *sec_type, const char *option, char *val, size_t val_len);
bool uci_get_option_db(const char *pkg_name, const char *sec_type, const char *option, char *val, size_t val_len);
bool uci_set_option(const char *pkg_name, const char *section, char *option, char *value);
bool get_boolean_val(const char *value);
bool uci_configure_al_iface();
const char *get_ap_radio_name(char *ap_name);
bool uci_set_wireless_interface_option(char *package_name, char *ifname, char *option, char *value);
bool uci_get_wireless_interface_option(char *package_name, char *ifname, char *option, char *value, size_t vlen);
bool uci_check_wifi_iface(char *package_name, char *ifname);
bool uci_add_new_sec(char *package_name, char *sec_name);
bool uci_add_wireless_iface_sec(char *package_name, char *interface_name);
bool uci_del_wireless_interface_sec(char *package_name, char *ifname);
void uci_free_list_of_1905_interfaces(char **x, INT8U nr);
char **uci_get_list_of_1905_interfaces(uint8_t *nr);
#endif
